==> ixnetwork_restpy-1.1.3.tar.gz: ixnetwork_restpy-1.1.3/ixnetwork_restpy/testplatform/sessions/ixnetwork/vport/protocols/umhtarget_7fd706c876de38f4f7aea952e9a68a18.py <==
# MIT LICENSE
#
# Copyright 1997 - 2020 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE. 
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files
from typing import List, Any, Union


class UmhTarget(Base):
    """This object represent RT
    The UmhTarget class encapsulates a required umhTarget resource which will be retrieved from the server every time the property is accessed.
    """

    __slots__ = ()
    _SDM_NAME = 'umhTarget'
    _SDM_ATT_MAP = {
        'TargetList': 'targetList',
    }
    _SDM_ENUM_MAP = {
    }

    def __init__(self, parent, list_op=False):
        super(UmhTarget, self).__init__(parent, list_op)

    @property
    def TargetList(self):
        """
        Returns
        -------
        - list(dict(arg1:str[asNumber2 | as | ip],arg2:number,arg3:str,arg4:number,arg5:number,arg6:number,arg7:str)): Configures a route target to be exported while advertising UMH routes
        """
        return self._get_attribute(self._SDM_ATT_MAP['TargetList'])
    @TargetList.setter
    def TargetList(self, value):
        self._set_attribute(self._SDM_ATT_MAP['TargetList'], value)

    def update(self, TargetList=None):
        """Updates umhTarget resource on the server.

        Args
        ----
        - TargetList (list(dict(arg1:str[asNumber2 | as | ip],arg2:number,arg3:str,arg4:number,arg5:number,arg6:number,arg7:str))): Configures a route target to be exported while advertising UMH routes

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))

==> ixnetwork_restpy-1.1.4.tar.gz: ixnetwork_restpy-1.1.4/ixnetwork_restpy/testplatform/sessions/ixnetwork/vport/protocols/umhtarget_7fd706c876de38f4f7aea952e9a68a18.py <==
# MIT LICENSE
#
# Copyright 1997 - 2020 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE. 
import sys
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files
if sys.version_info >= (3, 5):
    from typing import List, Any, Union


class UmhTarget(Base):
    """This object represent RT
    The UmhTarget class encapsulates a required umhTarget resource which will be retrieved from the server every time the property is accessed.
    """

    __slots__ = ()
    _SDM_NAME = 'umhTarget'
    _SDM_ATT_MAP = {
        'TargetList': 'targetList',
    }
    _SDM_ENUM_MAP = {
    }

    def __init__(self, parent, list_op=False):
        super(UmhTarget, self).__init__(parent, list_op)

    @property
    def TargetList(self):
        """
        Returns
        -------
        - list(dict(arg1:str[asNumber2 | as | ip],arg2:number,arg3:str,arg4:number,arg5:number,arg6:number,arg7:str)): Configures a route target to be exported while advertising UMH routes
        """
        return self._get_attribute(self._SDM_ATT_MAP['TargetList'])
    @TargetList.setter
    def TargetList(self, value):
        self._set_attribute(self._SDM_ATT_MAP['TargetList'], value)

    def update(self, TargetList=None):
        """Updates umhTarget resource on the server.

        Args
        ----
        - TargetList (list(dict(arg1:str[asNumber2 | as | ip],arg2:number,arg3:str,arg4:number,arg5:number,arg6:number,arg7:str))): Configures a route target to be exported while advertising UMH routes

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))

    def find(self, TargetList=None):
        """Finds and retrieves umhTarget resources from the server.

        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve umhTarget resources from the server.
        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
        By default the find method takes no parameters and will retrieve all umhTarget resources from the server.

        Args
        ----
        - TargetList (list(dict(arg1:str[asNumber2 | as | ip],arg2:number,arg3:str,arg4:number,arg5:number,arg6:number,arg7:str))): Configures a route target to be exported while advertising UMH routes

        Returns
        -------
        - self: This instance with matching umhTarget resources retrieved from the server available through an iterator or index

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))

    def read(self, href):
        """Retrieves a single instance of umhTarget data from the server.

        Args
        ----
        - href (str): An href to the instance to be retrieved

        Returns
        -------
        - self: This instance with the umhTarget resources from the server available through an iterator or index

        Raises
        ------
        - NotFoundError: The requested resource does not exist on the server
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._read(href)
